@@ -1,5 +1,5 @@
 package MIDI::Simple::Drummer;
-our $VERSION = '0.00_01';
+our $VERSION = '0.00_03';
 
 use strict;
 use warnings;
@@ -141,7 +141,7 @@ sub beat_1 {
         'Ride Cymbal 1',
         'Ride Cymbal 2',
 #        'Tambourine', # Maybe...
-#        'Cowbell', # Ugh.
+#        'Cowbell', # Maybe not.
     ];
     for(1 .. $self->{-beats}) {
         my $n = $self->alternate($_, $args{-alternate});
@@ -292,7 +292,7 @@ This module is embroyonic but may yet grow into a giant reptilian
 monster that smashes Tokyo.
 
 Until then, this is just meant to be a robotic drummer and hide the
-ugliness of fooling with L<MIDI::Simple> parameters.
+L<MIDI::Simple> parameters.
 
 =head1 METHODS
 
@@ -300,7 +300,7 @@ ugliness of fooling with L<MIDI::Simple> parameters.
 
   my $d = MIDI::Simple::Drummer->new(%arguments);
 
-Far away in a distant galaxy... But nevermind that Luke, use The Source.
+Far away in a distant galaxy... But nevermind that, Luke. Use The Source.
 
 =head2 * phrases()
 
@@ -308,51 +308,57 @@ Return or set the number of phrases to play.
 
 =head2 * n2p(), p2n()
 
-Return %MIDI::notenum2percussion or %MIDI::percussion2notenum.
+Return C<%MIDI::notenum2percussion> or C<%MIDI::percussion2notenum>, a
+la L<MIDI/GOODIES>.
 
 =head2 * kit()
 
-Return note values for percussion names.
+Return note values for percussion names with
+C<%MIDI::notenum2percussion>.
 
 =head2 * metronome()
 
-Beats x Phases.
+Beats x Phases with the C<Pedal Hi-Hat> or whatever patch you supply.
 
 =head2 * count_in()
 
-And a-one, and a-two and a-one, two, three, four!</Lawrence Welk> ..11</FZ>
+And a-one and a-two and a-one, two, three!E<lt>E<sol>Lawrence WelkE<gt>
+..11E<lt>E<sol>FZE<gt>
 
-=head2 = * alternate()
+=head2 * alternate()
 
-Return the alternating backbeat of the rhythm. By default, this is the
-kick and snare.
+Return the alternating back-beat of the rhythm. By default, this is
+the kick and snare.
 
-=head2 = * option_patch()
+=head2 * option_patch()
 
-Return a patch name from a given patch or a random selection from a
-list of patches.
+Return a selection from a list of patches, if one is not given.
 
 =head2 * foo_beat()
 
-Append a bar of this anecdotal beat onto the event stream.  Indicate
-that we filled in the previous bar to crash on the first beat.
+This is a fictional, anecdotal "beat" that is added to the event
+stream. You can indicate that we filled in the previous bar, and do
+something exciting like crash on the first beat, by supplying the
+C<-fill> argument.
 
 =head2 * fill()
 
-Append a glop of filler cheese to the event stream and return the id
-for the chosen fill.  The C<N> parameter determines which fill will be
-played.  If C<N=0> or there is no C<Nth> fill, a random one is chosen.
+Append a drum-fill to the event stream and return the id for the
+selected fill. We try to play a different fill each time, so if the
+fill is the same as the C<-last>, or if there is no given fill to
+play, another is chosen.
 
 =head2 * write()
 
-This is just an alias for L<MIDI::Simple/write_score>.
+This is just an alias for L<MIDI::Simple/write_score> but with
+unimaginably intelligent bits.
 
 =head1 TO DO
 
-* Read the source TODO comments.
+* The source TODO comments.
   > grep TODO `perldoc -l MIDI::Simple::Drummer`
 
-* Make the beats and fills a user definable list of coderefs.
+* Make the beats and fills user definable lists of coderefs.
 
 * Allow smoother modification of the drum kit.
 
